from setuptools import setup

setup(name='caspi',
      version='0.1.1',
      url='https://github.com/DSMdongly/Caspi',
      license='MIT',
      author='Toygrammer',
      author_email='gdh0608@naver.com',
      description='Korean CStore API',
      packages=['caspi'],
      install_requires=['bs4', 'requests'])
